==> gamclass_0.57.tar.gz: gamclass/man/german.Rd <==
\name{german}
\alias{german}
\docType{data}
\title{
German credit scoring data
}
\description{
See website for details of data attributes
}
\usage{
german
}
\format{
  A data frame with 1000 observations on the following 21 variables.
  \describe{
    \item{\code{V1}}{a factor with levels \code{A11} \code{A12} \code{A13} \code{A14}}
    \item{\code{V2}}{a numeric vector}
    \item{\code{V3}}{a factor with levels \code{A30} \code{A31} \code{A32} \code{A33} \code{A34}}
    \item{\code{V4}}{a factor with levels \code{A40} \code{A41} \code{A410} \code{A42} \code{A43} \code{A44} \code{A45} \code{A46} \code{A48} \code{A49}}
    \item{\code{V5}}{a numeric vector}
    \item{\code{V6}}{a factor with levels \code{A61} \code{A62} \code{A63} \code{A64} \code{A65}}
    \item{\code{V7}}{a factor with levels \code{A71} \code{A72} \code{A73} \code{A74} \code{A75}}
    \item{\code{V8}}{a numeric vector}
    \item{\code{V9}}{a factor with levels \code{A91} \code{A92} \code{A93} \code{A94}}
    \item{\code{V10}}{a factor with levels \code{A101} \code{A102} \code{A103}}
    \item{\code{V11}}{a numeric vector}
    \item{\code{V12}}{a factor with levels \code{A121} \code{A122} \code{A123} \code{A124}}
    \item{\code{V13}}{a numeric vector}
    \item{\code{V14}}{a factor with levels \code{A141} \code{A142} \code{A143}}
    \item{\code{V15}}{a factor with levels \code{A151} \code{A152} \code{A153}}
    \item{\code{V16}}{a numeric vector}
    \item{\code{V17}}{a factor with levels \code{A171} \code{A172} \code{A173} \code{A174}}
    \item{\code{V18}}{a factor with levels \code{good} \code{bad}}
    \item{\code{V19}}{a factor with levels \code{A191} \code{A192}}
    \item{\code{V20}}{a factor with levels \code{A201} \code{A202}}
    \item{\code{V21}}{a numeric vector}
  }
}
% \details{
% %%  ~~ If necessary, more details than the __description__ above ~~
% }
\source{
\url{http://archive.ics.uci.edu/ml/datasets.html}
}
% \references{
% %%  ~~ possibly secondary sources and usages ~~
% }
\examples{
data(german)
}
\keyword{datasets}

==> gamclass_0.62.3.tar.gz: gamclass/man/german.Rd <==
\name{german}
\alias{german}
\docType{data}
\title{
German credit scoring data
}
\description{
See website for details of data attributes
}
\usage{
german
}
\format{
  A data frame with 1000 observations on the following 21 variables.
  \describe{
    \item{\code{V1}}{a factor with levels \code{A11} \code{A12} \code{A13} \code{A14}}
    \item{\code{V2}}{a numeric vector}
    \item{\code{V3}}{a factor with levels \code{A30} \code{A31} \code{A32} \code{A33} \code{A34}}
    \item{\code{V4}}{a factor with levels \code{A40} \code{A41} \code{A410} \code{A42} \code{A43} \code{A44} \code{A45} \code{A46} \code{A48} \code{A49}}
    \item{\code{V5}}{a numeric vector}
    \item{\code{V6}}{a factor with levels \code{A61} \code{A62} \code{A63} \code{A64} \code{A65}}
    \item{\code{V7}}{a factor with levels \code{A71} \code{A72} \code{A73} \code{A74} \code{A75}}
    \item{\code{V8}}{a numeric vector}
    \item{\code{V9}}{a factor with levels \code{A91} \code{A92} \code{A93} \code{A94}}
    \item{\code{V10}}{a factor with levels \code{A101} \code{A102} \code{A103}}
    \item{\code{V11}}{a numeric vector}
    \item{\code{V12}}{a factor with levels \code{A121} \code{A122} \code{A123} \code{A124}}
    \item{\code{V13}}{a numeric vector}
    \item{\code{V14}}{a factor with levels \code{A141} \code{A142} \code{A143}}
    \item{\code{V15}}{a factor with levels \code{A151} \code{A152} \code{A153}}
    \item{\code{V16}}{a numeric vector}
    \item{\code{V17}}{a factor with levels \code{A171} \code{A172} \code{A173} \code{A174}}
    \item{\code{V18}}{a factor with levels \code{good} \code{bad}}
    \item{\code{V19}}{a factor with levels \code{A191} \code{A192}}
    \item{\code{V20}}{a factor with levels \code{A201} \code{A202}}
    \item{\code{V21}}{a numeric vector}
  }
}
\details{
700 good and 300 bad credits with 20 predictor variables. Data from 1973 to 1975. Stratified sample from actual credits with bad credits heavily oversampled. A cost matrix can be used.
}
\source{
\url{http://archive.ics.uci.edu/ml/index.php}
}
\references{
Grömping, U. (2019). South German Credit Data: Correcting a Widely 
Used Data Set. Report 4/2019, Reports in Mathematics, Physics and 
Chemistry, Department II, Beuth University of Applied Sciences Berlin.
}
\examples{
data(german)
}
\keyword{datasets}
